==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <location filename="../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Информация PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Выполняется другая аутентификация. Пожалуйста, попробуйте позже.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Авторизация не удалась</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Авторизация не удалась по какой-то причине</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Ошибка PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Требуется аутентификация</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Идентификация:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="149"/>
        <source>PolicyKit Information</source>
        <translation>Информация PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Выполняется другая аутентификация. Пожалуйста, попробуйте позже.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization Failed</source>
        <translation>Авторизация не удалась</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="132"/>
        <source>Authorization failed for some reason</source>
        <translation>Авторизация не удалась по какой-то причине</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="144"/>
        <source>PolicyKit Error</source>
        <translation>Ошибка PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Требуется аутентификация</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Идентификация:</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
</TS>
